#!/bin/bash
#
# NAME
# ----
# - xymon_nut_status.sh
#
# DESCRIPTION
# -----------
# - External client script to poll a NUT server for a UPS's
#   AC "online" status, "replace battery" status, and 
#   report back to a Xymon Monitoring Server
#
# - The most current version of this script may be
#   found at http://www.revpol.com/xymon_nut_scripts
#
# - Instructions to integrate the output of this script to be monitored
#   and graphed by a Xymon server may also be found at the above URL
#
# - If you find this script useful, I'd love to know. Send me an email!
#
# Author
# ------
# William A. Arlofski
# Reverse Polarity, LLC
# 860-824-2433 Office
# http://www.revpol.com/
# 
# HISTORY
# -------
# - 20100802 - Original release. This new "ups-status" test added to the
#              rest of the xymon_nut_*.sh scripts
#
###############################################################################
#
# Copyright (C) 2010 William A. Arlofski - waa-at-revpol-dot-com
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License, version 2, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# or visit http://www.gnu.org/licenses/gpl.txt
#
###############################################################################
# ----------------------------
# Define local system binaries
# ----------------------------
UPSC="/usr/bin/upsc"

# ----------------------
# Set up Xymon and
# other script variables
# ----------------------
COLUMN="ups-status"
COLOR="green"
MSG=""

nutserver="host.example.com"
upslist="apc1000"
datatest="ups\.status:"

# Status strings to test for - YOUR UPS may 
# report differnent statuses, test carefully
# Separate multiple striongs with "\|" as
# demonstrated in the "redtest" below
# ------------------------------------------
yellowtest="OB"   # OB = On Battery for APC1000
redtest="RB\|OV"  # RB = Replace Battery for APC1000

# Add an administrative message to the top of the report page
# -----------------------------------------------------------
ADMINMSG="- UPS AC and Battery Status for $upslist on $nutserver"

# ---------------------------------------------------------------------------
# Nothing should need to be modified below this line
# ---------------------------------------------------------------------------

# Query information from the NUT server for each UPS
# it is physically connected to and monitoring
# --------------------------------------------------
for ups in $upslist; do
  # Query the NUT server for the UPS AC/Battery Status
  # --------------------------------------------------
  data=$("$UPSC" "$ups"@"$nutserver" 2>&1 | "$GREP" "$datatest" | "$CUT" -d' ' -f2)

  # Substitute plain language status messages for 
  # the two-character status messages reported by UPS
  # -------------------------------------------------
  data_text=$(echo "$data" | "$SED" -e 's/OL/On AC Line Power/'   \
                                    -e 's/OB/On Battery Power/'   \
                                    -e 's/RB/- REPLACE BATTERY!/' \
                                    -e 's/OV/- OVERLOAD!/')

  # If there is a problem querying the NUT server assign the COLOR
  # variable and send an appropriate message to the Xymon server
  # --------------------------------------------------------------
  if [ -z "$data" ]; then
    COLOR="yellow"
    MSG="Problem retreiving data for $upslist from $nutserver"
    
    else

      # Determine if the UPS is reporting RB (Replace Battery)
      # Or OV (Over Load) and assign appropriate value to the
      # COLOR variable
      # ------------------------------------------------------
      if [ ! -z "$(echo "$data" | "$GREP" "$redtest")" ]; then
        COLOR="red"
         # Determine if UPS is reporting OB (On Battery)
         # ---------------------------------------------
         elif [ ! -z "$(echo "$data" | "$GREP" "$yellowtest")" ]; then
          COLOR="yellow"
      fi

      # Append the test color, UPS name, the raw
      # status message and it's plain language
      # value to the MSG variable
      # ----------------------------------------
      MSG="&$COLOR $ups : ($data) $data_text"
  fi
done

# Prepend the ADMINMSG to the message 
# to be returned to the Xymon server
#------------------------------------
MSG="$ADMINMSG

${MSG}"


# Report status to Xymon Server
# -----------------------------
$BB $BBDISP "status $MACHINE.$COLUMN $COLOR $("$DATE")

${MSG}
"
exit 0
